ifndef iscart
ifdef is128k
cas_in_open   equ &BC77
cas_in_direct equ &BC83
cas_in_close  equ &BC7A
cas_noisy     equ &BC6B

tilesstr:    defb "TILES.BIN"   ; TILE GRAPHICS
tilesstrl    equ 9
spritesstr:  defb "SPRITES.BIN" ; SPRITE DEFINITIONS
spritesstrl  equ 11
dictstr:     defb "DICT.BIN" ; SPRITE DEFINITIONS
dictstrl     equ 8

str_loadtiles:   defb "LOADING TILES",255
str_loadtiles2:  defb "LOADING SPRITES",255
str_loadtiles3:  defb "LOADING DICT",255
endif

;ifndef is128k
;cas_in_open   equ &BC77
;cas_in_direct equ &BC83
;cas_in_close  equ &BC7A
;cas_noisy     equ &BC6B

;blockstr     defb "QUEST2.BIN"   ; TILE GRAPHICS
;blockstrl    equ 10
;endif

;loadfile
;  ld a,1
;  call cas_noisy     ; DISABLE LOADING MESSAGES 
;  push de
;  call cas_in_open
;  pop de
;  ex de,hl
;  call cas_in_direct
;  jp cas_in_close
;endif

pickaxeinsert equ &412c
arrowleftinsert equ pickaxeinsert + 4

detectram:
ifndef iscart

; AS PROGRAM IS TOO BIG AND OVERWRITES LOADING FIRMWARE, WE NEED TO SPLIT IT IN TWO.
; THE FIRST PART IS LOADED AS NORMAL.
; THE SECOND PART IS LOADED AS A DATA BLOCK INTO &C000 AND MOVED TO &A000
;ifndef is128k
;  ; LOAD SECOND BLOCK GFX DATA INTO EXTRA RAM BANK 1
;  ld hl,blockstr
;  ld b,blockstrl
;  ld de,&C000
;  call loadfile
;  ; COPY TO CORRECT PLACE IN MEMORY
;  ld de,&A000
;  ld hl,&C000
;  ld bc,&0900
;  ldir
;  ld hl,&C000
;  ld bc,&0900
;  call clearmem
;endif



ifdef is128k
  ld hl,str_loadtiles
  call printstronce

  call bankswitchtiles
  ; LOAD TILE GFX DATA INTO EXTRA RAM BANK 1
  ld hl,tilesstr
  ld b,tilesstrl
  ld de,&4000
  call loadfile

  ; WE HAVE EXTRA MEM
  ; MAKE SURE PICKAXE SPRITE PTR LOCATION IS SET IN TABLE
  ; WE NEED PICKAXE IMAGE TO BE AVAILABLE AT ALL TIMES FOR FIRING
  ; BUT WE ALSO NEED IT IN LOOKUP TABLE FOR OBJECT PICKUP
  ld bc,pickaxeleft 
  ld (pickaxeinsert),bc
  ld bc,arrowleft
  ld (arrowleftinsert),bc
  call bankswitchnormal

  ld hl,str_loadtiles2
  call printstronce

  call bankswitchsprites
  ; LOAD SPRITE DATA INTO EXTRA RAM BANK 2
  ld hl,spritesstr
  ld b,spritesstrl
  ld de,&4000
  call loadfile
  
  ; SWITCH BACK TO MAIN 64k       
  call bankswitchnormal

  ld hl,str_loadtiles3
  call printstronce

  call bankswitchdict
  ; LOAD SPRITE DATA INTO EXTRA RAM BANK 3
  ld hl,dictstr
  ld b,dictstrl
  ld de,&4000
  call loadfile
  
  ; SWITCH BACK TO MAIN 64k       
  call bankswitchnormal

endif
endif
ret
; INPUT
; A = BANK TO SWITCH
; &C4,&C5,&C6,&C7
; SWAPS &4000-&7FFF WITH EXTRA BANKS 1-4

ifdef iscart
romswitchnormal:
  push bc
  ; DISABLE UPPER LOWER ROM
  ld bc,&7f00+%10001100
  out (c),c
  ld bc,&df00
  out (c),c
  pop bc
ret
romswitchsprites:
  push bc
  ld bc,&df86
  out (c),c
  ; ENABLE UPPER ROM
  ld bc,&7f00+%10001001
  out (c),c
  pop bc
ret
romswitchtiles:
  push bc
  ld bc,&df85
  out (c),c
  ; ENABLE UPPER ROM
  ld bc,&7f00+%10001001
  pop bc
ret
romswitchdict:
  push bc
  ld bc,&df87
  out (c),c
  ; ENABLE UPPER ROM
  ld bc,&7f00+%10001001
  pop bc
ret

endif

bankswitchdict:
  ld a,&C6
  ld b,&7F
  out (c),a
ret
bankswitchsprites:
  ld a,&C5
  ld b,&7F
  out (c),a
ret
bankswitchtiles:
  ld a,&C4
  ld b,&7F
  out (c),a
ret
bankswitchnormal:
  ld a,&C0
bankswitch:
  ld b,&7F
  out (c),a
ret

